@@ -13,7 +13,7 @@ our @ISA = qw(Rose::HTML::Form::Field Rose::HTML::Form::Field::Collection);
 
 use Rose::HTML::Form::Constants qw(FF_SEPARATOR);
 
-our $VERSION = '0.546';
+our $VERSION = '0.548';
 
 # Multiple inheritence never quite works out the way I want it to...
 Rose::HTML::Form::Field::Collection->import_methods
@@ -255,7 +255,7 @@ sub validate
   if($self->required)
   {
     my @missing;
-$DB::single = 1;
+
     foreach my $field ($self->fields)
     {
       no warnings 'uninitialized';
@@ -280,6 +280,16 @@ $DB::single = 1;
   return $self->SUPER::validate(@_);
 }
 
+sub disabled
+{
+  my($self) = shift;
+
+  foreach my $field ($self->fields)
+  {
+    $field->disabled(@_)  if($field->can('disabled'));
+  }
+}
+
 sub message_for_error_id
 {
   my($self, %args) = @_;
@@ -649,6 +659,10 @@ In the example below, the method's job is to decompose a full name into first, m
       };      
     }
 
+=item B<disabled [BOOL]>
+
+This method calls the C<disabled()> method on all L<fields|/fields> that possess such a method, passing all arguments.  Set to true to disable all eligible sub-fields, false to enable them.
+
 =item B<field NAME [, VALUE]>
 
 Get or set the field specified by NAME.  If only a NAME argument is passed, then the field stored under the name NAME is returned.  If no field exists under that name exists, then undef is returned.
