@@ -7,6 +7,8 @@ use Carp();
 use Rose::HTML::Form::Field::Option::Container;
 our @ISA = qw(Rose::HTML::Form::Field::Option::Container);
 
+our $VERSION = '0.548';
+
 __PACKAGE__->add_required_html_attrs(
 {
   name => '',
@@ -24,10 +26,18 @@ __PACKAGE__->add_valid_html_attrs
   'onchange',    # %Script;       #IMPLIED  -- the element value was changed --
 );
 
-our $VERSION = '0.544';
-
 sub multiple { shift->html_attr('multiple', @_) }
 
+sub internal_value
+{
+  my($self) = shift;
+
+  return $self->SUPER::internal_value(@_)  if($self->multiple);
+
+  my($value) =  $self->SUPER::internal_value(@_);
+  return $value;
+}
+
 1;
 
 __END__
@@ -128,7 +138,118 @@ Convenience alias for L<add_options()|/add_options>.
 
 =item B<add_options OPTIONS>
 
-Adds options to the select box.  OPTIONS may be a reference to a hash of value/label pairs, an ordered list of value/label pairs, a reference to an array of values, or a list of objects that are of, or inherit from, the classes L<Rose::HTML::Form::Field::Option> or L<Rose::HTML::Form::Field::OptionGroup>. Passing an odd number of items in the value/label argument list causes a fatal error. Options passed as a hash reference are sorted by value according to the default behavior of Perl's built-in L<sort()|perlfunc/sort> function.  Options are added to the end of the existing list of options.
+Adds options to the select box.  OPTIONS may take the following forms.
+
+A reference to a hash of value/label pairs:
+
+    $field->add_options
+    (
+      {
+        value1 => 'label1',
+        value2 => 'label2',
+        ...
+      }
+    );
+
+An ordered list of value/label pairs:
+
+    $field->add_options
+    (
+      value1 => 'label1',
+      value2 => 'label2',
+      ...
+    );
+
+(Option values and labels passed as a hash reference are sorted by value according to the default behavior of Perl's built-in L<sort()|perlfunc/sort> function.)
+
+A reference to an array of containing B<only> plain scalar values:
+
+    $field->add_options([ 'value1', 'value2', ... ]);
+
+A list or reference to an array of L<Rose::HTML::Form::Field::Option> or L<Rose::HTML::Form::Field::OptionGroup> objects:
+
+    $field->add_options
+    (
+      Rose::HTML::Form::Field::Option->new(...),
+      Rose::HTML::Form::Field::OptionGroup->new(...),
+      Rose::HTML::Form::Field::Option->new(...),
+      ...
+    );
+
+    $field->add_options
+    (
+      [
+      Rose::HTML::Form::Field::Option->new(...),
+      Rose::HTML::Form::Field::OptionGroup->new(...),
+      Rose::HTML::Form::Field::Option->new(...),
+        ...
+      ]
+    );
+
+A list or reference to an array containing a mix of value/label pairs, value/hashref pairs, and L<Rose::HTML::Form::Field::Option> or L<Rose::HTML::Form::Field::OptionGroup> objects:
+
+    @args = 
+    (
+      # value/label pair
+      value1 => 'label1',
+
+      # option group object
+      Rose::HTML::Form::Field::OptionGroup->new(...),
+
+      # value/hashref pair
+      value2 =>
+      {
+        label => 'Some Label',
+        id    => 'my_id',
+        ...
+      },
+
+      # option object
+      Rose::HTML::Form::Field::Option->new(...),
+
+      ...
+    );
+
+    $field->add_options(@args);  # list
+    $field->add_options(\@args); # reference to an array
+
+B<Please note:> the second form (passing a reference to an array) requires that at least one item in the referenced array is not a plain scalar, lest it be confused with "a reference to an array of containing only plain scalar values."
+
+All options are added to the end of the existing list of options.
+
+Option groups may also be added by nesting another level of array references.  For example, this:
+
+    $field = Rose::HTML::Form::Field::SelectBox->new(name => 'fruits');
+
+    $field->options(apple  => 'Apple',
+                    orange => 'Orange',
+                    grape  => 'Grape');
+
+    $group = Rose::HTML::Form::Field::OptionGroup->new(label => 'Others');
+
+    $group->options(juji  => 'Juji',
+                    peach => 'Peach');
+
+    $field->add_options($group);
+
+is equivalent to this:
+
+    $field = 
+      Rose::HTML::Form::Field::SelectBox->new(
+        name    => 'fruits',
+        options =>
+        [
+          apple  => 'Apple',
+          orange => 'Orange',
+          grape  => 'Grape',
+          Others =>
+          [
+            juji  => { label => 'Juji' },
+            peach => { label => 'Peach' },
+          ],
+        ]);
+
+    $field->add_options($group);
 
 =item B<add_value VALUE>
 
@@ -146,6 +267,10 @@ This is an alias for the L<options|/options> method.
 
 Returns true if VALUE is selected in the select box, false otherwise.
 
+=item B<internal_value>
+
+If L<multiple|/multiple> is true, a reference to an array of selected values is returned in scalar context, and a list of selected values is returned in list context.  Otherwise, the selected value is returned (or undef if no value is selected).
+
 =item B<labels [LABELS]>
 
 Get or set the labels for all values.  If LABELS is a reference to a hash or a list of value/label pairs, then LABELS replaces all existing labels.  Passing an odd number of items in the list version of LABELS causes a fatal error.
