@@ -4,10 +4,17 @@ use strict;
 
 use Carp();
 
+use Rose::HTML::Object::Errors qw(:string);
+
 use Rose::HTML::Form::Field::WithContents;
 our @ISA = qw(Rose::HTML::Form::Field::WithContents);
 
-our $VERSION = '0.34';
+our $VERSION = '0.548';
+
+use Rose::Object::MakeMethods::Generic
+(
+  scalar => 'maxlength',
+);
 
 __PACKAGE__->add_valid_html_attrs
 (
@@ -34,7 +41,7 @@ __PACKAGE__->add_boolean_html_attrs
 sub html_element  { 'textarea' }
 sub xhtml_element { 'textarea' }
 
-sub value { shift->contents(@_) }
+sub value { shift->input_value(@_) }
 
 sub escape_html_contents { 1 }
 
@@ -68,6 +75,28 @@ sub size
   return $self->cols . 'x' . $self->rows;
 }
 
+sub validate
+{
+  my($self) = shift;
+
+  my $ok = $self->SUPER::validate(@_);
+  return $ok  unless($ok);
+
+  my $value = $self->input_value;
+  return 1  unless(defined $value && length $value);
+
+  my $maxlength = $self->maxlength;
+
+  my $name = sub { $self->label || $self->name };
+
+  if(defined $maxlength && length($value) > $maxlength)
+  {
+    $self->add_error_id(STRING_OVERFLOW, { label => $name, maxlength => $maxlength });
+    return 0;
+  }
+
+  return 1;
+}
 1;
 
 __END__
@@ -160,6 +189,10 @@ Constructs a new L<Rose::HTML::Form::Field::TextArea> object based on PARAMS, wh
 
 Get or set the contents of the text area.  If a TEXT argument is present, it is passed to L<input_value()|Rose::HTML::Form::Field/input_value> and the return value of that method call is then returned. Otherwise, L<output_value()|Rose::HTML::Form::Field/output_value> is called with no arguments.
 
+=item B<maxlength [INT]>
+
+Get or set the maximum length of the input value.  Note that this is not an HTML attribute; this limit is enforced by the L<validate|Rose::HTML::Form::Field/validate> method, not by the web browser.
+
 =item B<size [COLSxROWS]>
 
 Get or set the number of columns and rows (C<cols> and C<rows>) in the text area in the form of a string "COLSxROWS".  For example, "40x3" means 40 columns and 3 rows.  If the size argument is not in the correct format, a fatal error will occur.
