@@ -3,11 +3,12 @@ package Rose::HTML::Form::Field::Time::Hours;
 use strict;
 
 use Rose::HTML::Object::Errors qw(:time);
+use Rose::HTML::Object::Messages qw(:time);
 
 use Rose::HTML::Form::Field::Text;
 our @ISA = qw(Rose::HTML::Form::Field::Text);
 
-our $VERSION = '0.541';
+our $VERSION = '0.547';
 
 use Rose::Object::MakeMethods::Generic
 (
@@ -19,6 +20,13 @@ __PACKAGE__->add_required_html_attrs(
   size => 2,
 });
 
+sub init
+{
+  my($self) = shift;
+  $self->label_id(FIELD_LABEL_HOUR);
+  $self->SUPER::init(@_);
+}
+
 sub validate
 {
   my($self) = shift;
@@ -61,7 +69,9 @@ __DATA__
 
 [% LOCALE en %]
 
-TIME_INVALID_HOUR = "Invalid hour."
+FIELD_LABEL_HOUR       = "Hour"
+FIELD_ERROR_LABEL_HOUR = "hour"
+TIME_INVALID_HOUR      = "Invalid hour."
 
 [% LOCALE de %]
 
